import { afterEach, beforeEach, describe, expect, it, vi } from 'vitest';
import shell from 'shelljs';
import { initDb } from '.';
import { getRte, putRte } from './rte';

import { putRtept } from './rtept';

const test = it;
const jest = vi;

declare global {
  var db: any;
  var dbReady: boolean;
}

const originalDb = globalThis.db;
const originalDateNow = globalThis.Date.now;

describe('The rtept module with a real db', () => {
  beforeEach(async () => {
    await initDb({});
    globalThis.Date.now = () => 0;
  });
  afterEach(async () => {
    try {
      await db.destroy();
    } catch (err) {
//      console.error(err);
      shell.exec('rm -rf  \$*\$');
    }
    db = undefined;
    globalThis.Date.now = originalDateNow;
  });
  it('can write a rtept inside a rte', async () => {
    const idRte = 'whatever';
    const rtept: Rtept = {
      $: { lat: 2, lon: 2 },
    };
    const rte0: Rte = {
      name: 'A new route',
      rtept: [
        {
          $: { lat: 0, lon: 0 },
        },
        {
          $: { lat: 1, lon: 1 },
        },
      ],
    };
    const rte1: Rte = {
      name: 'A new route',
      rtept: [
        {
          $: { lat: 0, lon: 0 },
        },
        {
          $: { lat: 2, lon: 2 },
        },
      ],
    };

    const rtePut = await putRte({ id: idRte, rte: rte0 });
    expect(rtePut).toEqual(rte0);
    const rtePutRtept = await putRtept({ idRte, index: 1, rtept });
    expect(rtePutRtept).toEqual(rte1);
    const rteGetRtept = await getRte({ id: idRte });
    expect(rteGetRtept).toEqual(rte1);
  });
});
